jQuery(function ($) {

	if ($('#bgc-form form').length) {
		// Generate years dropdown
		var select = $('#year'),
			thisYear = new Date().getFullYear();

		for (var i = 0; i <= 100; i++) {
			var year = thisYear - i;

			$('<option>', { value: year, text: year }).appendTo(select);
		}

		if (select.data('selected')) {
			select.val(select.data('selected'));
		};

		// Generate months dropdown
		var select = $('#month'),
			monthNames = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];

		for (var i = 0; i <= 11; i++) {
			var value = ('0' + (i + 1)).slice(-2);

			$('<option>', { value: value, text: value + ' - ' + monthNames[i] }).appendTo(select);
		}

		if (select.data('selected')) {
			select.val(select.data('selected'));
		};

		// Generate days dropdown
		var select = $('#day');

		for (var i = 1; i <= 31; i++) {
			var value = ('0' + i).slice(-2);

			$('<option>', { value: value, text: value }).appendTo(select);
		}

		if (select.data('selected')) {
			select.val(select.data('selected'));
		};

		// Generate hours dropdown
		var select = $('#hour');

		for (var i = 0; i <= 12; i++) {
			var value = ('0' + i).slice(-2);

			$('<option>', { value: value, text: value }).appendTo(select);
		}

		if (select.data('selected')) {
			select.val(select.data('selected'));
		};

		// Generate minutes dropdown
		var select = $('#minute');

		for (var i = 0; i <= 59; i++) {
			var value = ('0' + i).slice(-2);

			$('<option>', { value: value, text: value }).appendTo(select);
		}

		if (select.data('selected')) {
			select.val(select.data('selected'));
		};

		if ($('#location').length) {
			new Autocomplete('location', {
				disableCloseOnSelect: false,
				delay: 250,
				howManyCharacters: 2,
				onSearch: ({ currentValue }) => {
					return new Promise((resolve) => {
						fetch(`https://app.bodygraphchart.com/api/v2/locations/search?query=${encodeURI(currentValue)}&token=${$('#location').data('api-key')}`)
							.then((response) => response.json())
							.then((data) => {
								resolve(data.result);
							})
							.catch((error) => {
								console.error(error);
						});
					});
				},
				onResults: ({ currentValue, matches, template, classGroup }) => {
					const regex = new RegExp(currentValue, 'gi');

					return matches === 0 ? template : matches.map((el, index, array) => {
						return `<li>${el.formatted_name.replace(regex, (str) => `<span class="auto-matched">${str}</span>`)}</li>`;
					}).join('');
				},
				onSubmit: ({ index, element, object, results }) => {
					element.value = object.formatted_name;

					document.getElementById('timezone').value = object.timezone;
				}
			});
		}

		var form = $('#bgc-form form');

		form.on('submit', function (evt) {
			evt.preventDefault();

			form.addClass('loading');

			$('.form-error').html('');

			$.post(form.attr('action'), form.serializeArray(), function (data) {
				if (data.status == 'success') {
					window.location.href = data.redirect_to;
				} else {
					$(`<div class="validation-message-error">${data.message}</div>`).appendTo('.form-error');
				}
			})
				.fail(function () {
					$('<div class="validation-message-error">Oops. Something went wrong. Please try again later.</div>').appendTo('.form-error');
				})
				.always(function () {
					form.removeClass('loading');
				});
		});
	}

	if (typeof bgc !== 'undefined') {
		var data = bgc.data;

		for (const [key, value] of Object.entries(data.Design)) {
			$('.design').append(`
				<div class="box-item" style="background: ${bgc.colors.design_channels}; color: ${bgc.colors.design_channels_text}">
					${getIcon(key, bgc.colors.design_channels_text)}
					<label>${value.Gate}.${value.Line}</label>
					<div class="hdapi-fixing-state">${getFixingStateIcon(value.FixingState, bgc.colors.design_channels_text)}</div>
				</div>
			`);
		}

		for (const [key, value] of Object.entries(data.Personality)) {
			$('.personality').append(`
				<div class="box-item" style="background: ${bgc.colors.personality_channels}; color: ${bgc.colors.personality_channels_text}">
					<div class="hdapi-fixing-state">${getFixingStateIcon(value.FixingState, bgc.colors.personality_channels_text)}</div>
					<label>${value.Gate}.${value.Line}</label>
					${getIcon(key, bgc.colors.personality_channels_text)}
				</div>
			`);
		}

		delete data.Design.Chiron;
		delete data.Personality.Chiron;

		delete data.Design.Lilith;
		delete data.Personality.Lilith;

		// Arrows
		// Digestion
		if (data.Variables.Digestion == 'left') {
			$('#variable-digestion svg').addClass('reverse');
		}

		$(`<span>${data.Design.Sun.Tone} <sub>${data.Design.Sun.Color}</sub></span>`).insertAfter('#variable-digestion svg');

		// Environment
		if (data.Variables.Environment == 'left') {
			$('#variable-environment svg').addClass('reverse');
		}

		$(`<span>${data.Design['North Node'].Tone} <sub>${data.Design['North Node'].Color}</sub></span>`).insertAfter('#variable-environment svg');

		// Awareness
		if (data.Variables.Awareness == 'left') {
			$('#variable-awareness svg').addClass('reverse');
		}

		$(`<span><sub>${data.Personality.Sun.Color}</sub> ${data.Personality.Sun.Tone}</span>`).insertBefore('#variable-awareness svg');

		// Perspective
		if (data.Variables.Perspective == 'left') {
			$('#variable-perspective svg').addClass('reverse');
		}

		$(`<span><sub>${data.Personality['North Node'].Color}</sub> ${data.Personality['North Node'].Tone}</span>`).insertBefore('#variable-perspective svg');

		$('svg #bg').html(bgc.background);

		if ($('svg #bg path').length) {
			$('svg #bg path').attr('fill', bgc.colors.background);
		}

		if ($('#ChannelBorders').length) {
			$('#ChannelBorders').attr('stroke', bgc.colors.channels_border);
		}

		$('#Centers g').each(function (key, value) {
			if ($(value).children(':first')) {
				$(value).children(':first')
					.attr('stroke', bgc.colors.centers_border);
			}
		});

		if (!$('svg.hdapi-svg-style').hasClass('hdapi-svg-karen')) {
			document.querySelectorAll('svg text')
				.forEach((el) => {
					el = el.previousElementSibling,
						gateNumber = el.getAttribute('id');

					if (el.tagName == 'circle') {
						gateNumber = gateNumber.replace('_', '');
					}

					el.style.fill = bgc.colors.gates_text;

					el.nextElementSibling
						.style.fill = bgc.colors.gates;

					if (hasGate(data, gateNumber)) {
						el.style.fill = bgc.colors.active_gates;

						el.nextElementSibling
							.style.fill = bgc.colors.active_gates_text;
					}
				});
		}

		document.querySelectorAll('svg [id^=design-], svg [id^=personality-]')
			.forEach((el) => {
				let gateNumber = el.getAttribute('id')
					.split('-')[1];

				let designValues = Object.values(data.Design),
					personalityValues = Object.values(data.Personality);

				let designGate = null;

				for (const key in designValues) {
					if (designValues[key].Gate == gateNumber) {
						designGate = true;
					}
				}

				let personalityGate = null;

				for (const key in personalityValues) {
					if (personalityValues[key].Gate == gateNumber) {
						personalityGate = true;
					}
				}

				if (designGate != null && personalityGate != null) {
					if (document.querySelector('svg.hdapi-svg-style').classList.contains('hdapi-line-style-fill')) {
						document.querySelector(`svg #design-${gateNumber}`)
							.style.fill = bgc.colors.design_channels;

						document.querySelector(`svg #personality-${gateNumber}`)
							.style.fill = bgc.colors.personality_channels;
					} else {
						document.querySelector(`svg #design-${gateNumber}`)
							.style.stroke = bgc.colors.design_channels;

						document.querySelector(`svg #personality-${gateNumber}`)
							.style.stroke = bgc.colors.personality_channels;
					}

					fixLine(el, 'both-' + gateNumber);
				} else if (designGate != null) {
					if (document.querySelector('svg.hdapi-svg-style').classList.contains('hdapi-line-style-fill')) {
						el.style.fill = bgc.colors.design_channels;
					} else {
						el.style.stroke = bgc.colors.design_channels;
					}

					fixLine(el, 'design-' + gateNumber);
				} else if (personalityGate != null) {
					if (document.querySelector('svg.hdapi-svg-style').classList.contains('hdapi-line-style-fill')) {
						el.style.fill = bgc.colors.personality_channels;
					} else {
						el.style.stroke = bgc.colors.personality_channels;
					}

					fixLine(el, 'personality-' + gateNumber);
				}
			});

		if (document.getElementById('fix-20-57-10-34-20-34-10-57-2')) {
			fixLines();
		}

		for (let [key, value] of Object.entries(data.UnconsciousCenters)) {
			let el = document.querySelector(`svg #${value.replace(/\s+/g, '-').toLowerCase()}`);

			if (el) {
				el.style.fill = bgc.colors.design_centers;
			}
		}

		for (let [key, value] of Object.entries(data.ConsciousCenters)) {
			let el = document.querySelector(`svg #${value.replace(/\s+/g, '-').toLowerCase()}`);

			if (el) {
				el.style.fill = bgc.colors.personality_centers;
			}
		}

		for (let [key, value] of Object.entries(data.DefinedCenters)) {
			let el = document.querySelector(`svg #${value.replace(/\s+/g, '-').toLowerCase()}`);

			// if (el && el.getAttribute('fill') == '#FFFFFF') {
			if (el && $(el).css('fill') == 'rgb(255, 255, 255)') {
				el.style.fill = bgc.colors.design_centers;
			}
		}

		if (bgc.colors.traditionalCenter) {
			for (let [key, value] of Object.entries(data.DefinedCenters)) {
				let el = document.querySelector(`svg #${value.replace(/\s+/g, '-').toLowerCase()}`);

				if (el) {
					el.style.fill = bgc.colors[value.replace(/\s+/g, '_')];
				}
			}
		}

		if (document.querySelector('svg.hdapi-svg-style').classList.contains('hdapi-svg-karen')) {
			document.querySelectorAll('svg text')
				.forEach((el) => {
					el = el.previousElementSibling,
						gateNumber = el.getAttribute('id');

					if (el.tagName == 'circle') {
						gateNumber = gateNumber.replace('_', '');
					}

					if (el.parentElement.getAttribute('id') == 'HeadCenter' || el.parentElement.getAttribute('id') == 'GCenter') {
						if (hasGate(data, gateNumber)) {
							el.style.fill = '#000000';

							el.nextElementSibling
								.style.fill = '#FFFFFF';
						}

						if (el.parentElement.querySelector('#head-center')) {
							if (el.parentElement.querySelector('#head-center').style.fill == 'rgb(79, 36, 53)') {
								if (hasGate(data, gateNumber)) {
									el.style.fill = '#FFFFFF';

									el.nextElementSibling
										.style.fill = '#000000';
								}
							} else {
								if (el.style.fill == 'rgb(0, 0, 0)') {
									el.nextElementSibling
										.style.fill = '#FFFFFF';
								} else {
									el.nextElementSibling
										.style.fill = '#000000';
								}
							}
						}

						if (el.parentElement.querySelector('#g-center')) {
							if (el.parentElement.querySelector('#g-center').style.fill == 'rgb(79, 36, 53)') {
								if (hasGate(data, gateNumber)) {
									el.style.fill = '#FFFFFF';

									el.nextElementSibling
										.style.fill = '#000000';
								}
							} else {
								if (!hasGate(data, gateNumber)) {
									el.nextElementSibling
										.style.fill = '#000000';
								}
							}
						}
					} else {
						el.style.fill = bgc.colors.gates_text;

						el.nextElementSibling
							.style.fill = 'black'; // bgc.colors.gates

						if (hasGate(data, gateNumber)) {
							el.style.fill = bgc.colors.active_gates;

							el.nextElementSibling
								.style.fill = bgc.colors.active_gates_text;
						}
					}
				});
		}

		$('#chart-properties').append(`
			<li>
				<input type="checkbox" checked>
				<i></i>
				<h2><span class="name">${bgc.translations.result.birth_date}</span> <span class="value">${data.Properties.BirthDateLocal}</span></h2>
			</li>
		`);

		$('#chart-properties').append(`
			<li>
				<input type="checkbox" checked>
				<i></i>
				<h2><span class="name">${bgc.translations.result.design_date}</span> <span class="value">${data.Properties.DesignDateUtc}</span></h2>
			</li>
		`);

		for (const property in data.Properties) {
			if (!data.Properties[property].name) {
				continue;
			}

			if (data.Properties[property].list) {
				continue;
			}

			$('#chart-properties').append(`
				<li class="${data.Properties[property].description ? 'has-description' : ''}">
					<input type="checkbox" checked>
					<i></i>
					<h2><span class="name">${data.Properties[property].name}</span> <span class="value">${data.Properties[property].option}</span></h2>
					<p>${data.Properties[property].description.replace(/(?:\r\n|\r|\n)/g, '<br>')}</p>
				</li>
			`);
		}
	}

});

function getIcon(name, color) {
	const icons = {
		'Sun': bgc.planet_icons.Sun.replace(/\${color}/g, color),
		'Earth': bgc.planet_icons.Earth.replace(/\${color}/g, color),
		'North Node': bgc.planet_icons['North Node'].replace(/\${color}/g, color),
		'South Node': bgc.planet_icons['South Node'].replace(/\${color}/g, color),
		'Moon': bgc.planet_icons.Moon.replace(/\${color}/g, color),
		'Mercury': bgc.planet_icons.Mercury.replace(/\${color}/g, color),
		'Venus': bgc.planet_icons.Venus.replace(/\${color}/g, color),
		'Mars': bgc.planet_icons.Mars.replace(/\${color}/g, color),
		'Jupiter': bgc.planet_icons.Jupiter.replace(/\${color}/g, color),
		'Saturn': bgc.planet_icons.Saturn.replace(/\${color}/g, color),
		'Uranus': bgc.planet_icons.Uranus.replace(/\${color}/g, color),
		'Neptune': bgc.planet_icons.Neptune.replace(/\${color}/g, color),
		'Pluto': bgc.planet_icons.Pluto.replace(/\${color}/g, color),
		'Chiron': bgc.planet_icons.Chiron.replace(/\${color}/g, color),
		'Lilith': bgc.planet_icons.Lilith.replace(/\${color}/g, color)
	};

	return icons[name];
}

function getFixingStateIcon(value, color) {
	let fixingStateIcon = '';

	if (value == 'Detriment') {
		fixingStateIcon = `<svg xmlns="http://www.w3.org/2000/svg" width="10" height="10" viewBox="0 0 10 10"><path d="M9.655 1.427L5.904 9.369a1 1 0 0 1-1.808.001L.338 1.428A1 1 0 0 1 1.242 0h7.508a1 1 0 0 1 .904 1.427z" fill="${color}" fill-rule="evenodd"/></svg>`;
	} else if (value == 'Exalted') {
		fixingStateIcon = `<svg xmlns="http://www.w3.org/2000/svg" width="10" height="10" viewBox="0 0 10 10"><path d="M9.698 8.57L5.899.601A1 1 0 0 0 4.095.598L.261 8.566A1 1 0 0 0 1.162 10h7.633a1 1 0 0 0 .903-1.43z" fill="${color}" fill-rule="evenodd"/></svg>`;
	} else if (value == 'Juxtaposed') {
		fixingStateIcon = `<svg xmlns="http://www.w3.org/2000/svg" width="10" height="10" viewBox="0 0 10 10"><path d="M9.808 6.549c.503.613-.051 1.463-.896 1.381l-2.146-.208-.871 1.757c-.344.694-1.449.692-1.792 0l-.871-1.757-2.146.208c-.847.082-1.398-.77-.896-1.381L1.467 5 .192 3.451c-.503-.612.05-1.463.896-1.381l2.146.208L4.104.52c.344-.694 1.449-.692 1.792 0l.871 1.757 2.146-.208c.845-.082 1.399.769.896 1.381L8.533 5l1.275 1.549z" fill="${color}"/></svg>`;
	}

	return fixingStateIcon;
}

function hasGate(data, gateNumber) {
	var design = Object.values(data.Design);

	for (var key in design) {
		if (design[key].Gate == gateNumber) {
			return true;
		}
	}

	var personality = Object.values(data.Personality);

	for (var key in personality) {
		if (personality[key].Gate == gateNumber) {
			return true;
		}
	}

	return false;
}

let gates = [];

function fixLine(el, gateNumber) {
	const parent = el.parentElement;

	if (parent.getAttribute('id') == 'fix-20-57-10-34-20-34-10-57-1') {
		el.style.display = 'block';
	}

	if (parent.getAttribute('id') == 'fix-20-57-10-34-20-34-10-57-2') {
		el.style.display = 'block';
	}

	gates.push(gateNumber);
}

function fixLines() {
	$ = jQuery;

	if (!gates.includes('both-34') && !gates.includes('personality-34') && !gates.includes('design-34')) {
		if (gates.includes('both-10')) {
			if (gates.includes('both-57') || gates.includes('personality-57') || gates.includes('design-57')) {
				$('svg #design-57, svg #personality-57').hide();

				let color1, color2;

				if (gates.includes('both-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('personality-57')) {
					color1 = bgc.colors.personality_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('design-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.design_channels;
				}

				$('svg #design_57-10').attr('fill', color1)
					.show()

				$('svg #personality_57-10').attr('fill', color2)
					.show();
			} else {
				$('svg #design-10, svg #personality-10').hide();

				$('svg #design_10-34').attr('fill', bgc.colors.design_channels)
					.show()

				$('svg #personality_10-34').attr('fill', bgc.colors.personality_channels)
					.show();
			}
		}

		if (gates.includes('personality-10')) {
			if (gates.includes('both-57') || gates.includes('personality-57') || gates.includes('design-57')) {
				$('svg #design-57, svg #personality-57').hide();

				let color1, color2;

				if (gates.includes('both-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('personality-57')) {
					color1 = bgc.colors.personality_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('design-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.design_channels;
				}

				$('svg #design_57-10').attr('fill', color1)
					.show()

				$('svg #personality_57-10').attr('fill', color2)
					.show();
			} else {
				$('svg #design-10, svg #personality-10').hide();

				$('svg #design_10-34, svg #personality_10-34').attr('fill', bgc.colors.personality_channels)
					.show();
			}
		}

		if (gates.includes('design-10')) {
			if (gates.includes('both-57') || gates.includes('personality-57') || gates.includes('design-57')) {
				$('svg #design-57, svg #personality-57').hide();

				let color1, color2;

				if (gates.includes('both-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('personality-57')) {
					color1 = bgc.colors.personality_channels;
					color2 = bgc.colors.personality_channels;
				}

				if (gates.includes('design-57')) {
					color1 = bgc.colors.design_channels;
					color2 = bgc.colors.design_channels;
				}

				$('svg #design_57-10').attr('fill', color1)
					.show()

				$('svg #personality_57-10').attr('fill', color2)
					.show();
			} else {
				$('svg #design-10, svg #personality-10').hide();

				$('svg #design_10-34, svg #personality_10-34').attr('fill', bgc.colors.design_channels)
					.show();
			}
		}
	}

	if (!gates.includes('both-10') && !gates.includes('personality-10') && !gates.includes('design-10')) {
		if (gates.includes('both-34')) {
			$('svg #design-34, svg #personality-34').hide();

			$('svg #design_34-10').attr('fill', bgc.colors.design_channels)
				.show()

			$('svg #personality_34-10').attr('fill', bgc.colors.personality_channels)
				.show();
		}

		if (gates.includes('personality-34')) {
			$('svg #design-34, svg #personality-34').hide();

			$('svg #design_34-10, svg #personality_34-10').attr('fill', bgc.colors.personality_channels)
				.show();
		}

		if (gates.includes('design-34')) {
			$('svg #design-34, svg #personality-34').hide();

			$('svg #design_34-10, svg #personality_34-10').attr('fill', bgc.colors.design_channels)
				.show();
		}
	}
}
