<?php

if (!defined('WPINC')) {
	die;
}

if (!function_exists('bgc_plugin_action_links')) {
	add_filter('plugin_action_links_bgc/bgc.php', 'bgc_plugin_action_links');

	function bgc_plugin_action_links( $links ) {
		$url = esc_url(add_query_arg('page', 'bgc-settings', get_admin_url() . 'options-general.php'));

		array_push($links, '<a href="' . $url . '">' .  __('Settings', 'bgc') . '</a>');

		return $links;
	}
}

if (!function_exists('bgc_admin_menu')) {
	add_action('admin_menu', 'bgc_admin_menu');

	function bgc_admin_menu() {
		add_submenu_page('options-general.php', __('BodyGraph Chart', 'bgc'), __('BodyGraph Chart', 'bgc'), 'administrator', 'bgc-settings', 'bgc_settings_page');
		add_submenu_page('options-general.php', __('BodyGraph Chart Translations', 'bgc'), '', 'administrator', 'bgc-translations', 'bgc_translations_page');

		remove_submenu_page('options-general.php', 'bgc-translations');
	}
}

if (!function_exists('bgc_admin_enqueue_scripts')) {
	add_action('admin_enqueue_scripts', 'bgc_admin_enqueue_scripts');

	function bgc_admin_enqueue_scripts($hook) {
		wp_enqueue_style('bgc-backend', BGC_PLUGIN_URL . 'assets/backend/css/settings.css');
		wp_enqueue_script('bgc-backend', BGC_PLUGIN_URL . 'assets/backend/js/settings.js', array('jquery'));
	}
}

if (!function_exists('bgc_admin_notices')) {
	function bgc_admin_notices() {
		if (!get_option('_bgc_api_key')) {
			if (isset($_GET['page']) && $_GET['page'] == 'bgc-settings') {
				return;
			}

			?>
			<div class="notification-item warning">
				<h2>
					<span class="icon">
						<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/icon-01.svg" alt="<?php _e('API Key', 'bgc'); ?>" class="img-fluid">
					</span>
					<?php _e('Please add your BodyGraph Chart API Key to connect your BodyGraph Chart account and enable chart generation', 'bgc'); ?>
				</h2>
				<a href="<?php echo add_query_arg('page', 'bgc-settings', admin_url('options-general.php')); ?>" class="green-btn">
					<?php _e('Add API Key', 'bgc'); ?>
				</a>
			</div>
			<?php
		}
	}

	add_action('admin_notices', 'bgc_admin_notices');
}

if (!function_exists('bgc_settings_page')) {
	function bgc_settings_page() {
		if (isset($_POST['submit'])) {
			$api_key = !empty($_POST['api_key']) ? esc_attr($_POST['api_key']) : '';
			$hd_content = !empty($_POST['hd_content']) ? esc_attr($_POST['hd_content']) : '';
			$chart_design = !empty($_POST['chart_design']) ? esc_attr($_POST['chart_design']) : '';
			$apps = !empty($_POST['apps']) ? $_POST['apps'] : null;
			$pdf_download = !empty($_POST['pdf_download']) ? true : false;
			$multiple_charts = !empty($_POST['multiple_charts']) ? true : false;
			$email_optional = !empty($_POST['email_optional']) ? true : false;
			$terms_checkbox = !empty($_POST['terms_checkbox']) ? true : false;
			$autocomplete_paid_orders = !empty($_POST['autocomplete_paid_orders']) ? true : false;

			$error = null;

			if ($api_key) {
				$request = wp_remote_get('https://app.bodygraphchart.com/api/v1/hd-content/?' . http_build_query([
					'token' => $api_key
				]));

				if (is_wp_error($request)) {
					$error = __('Something went wrong, please try again', 'bgc');
				}

				if (!$error) {
					$body = wp_remote_retrieve_body($request);

					$data = json_decode($body);

					if (!empty($data->error)) {
						$error = $data->error;
					} else {
						update_option('_bgc_api_key', $api_key);

						if (!$hd_content) {
							$hd_content = $data[0]->name;
						}

						update_option('_bgc_hd_content', $hd_content);

						update_option('_bgc_hd_content_list', $data);

						$request = wp_remote_get('https://app.bodygraphchart.com/api/v1/chart-design/?' . http_build_query([
							'token' => $api_key
						]));

						$body = wp_remote_retrieve_body($request);

						$data = json_decode($body);

						if (!$chart_design) {
							$chart_design = $data[0]->name;
						}

						update_option('_bgc_chart_design', $chart_design);

						update_option('_bgc_chart_design_list', $data);

						$request = wp_remote_get('https://app.bodygraphchart.com/api/v1/chart-design/?' . http_build_query([
							'token' => $api_key,
							'name' => $chart_design
						]));

						$body = wp_remote_retrieve_body($request);

						$data = json_decode($body);

						update_option('_bgc_chart_design_options', $data);

						$request = wp_remote_get('https://app.bodygraphchart.com/api/v1/app/?' . http_build_query([
							'token' => $api_key
						]));

						$body = wp_remote_retrieve_body($request);

						$data = json_decode($body);

						update_option('_bgc_apps', $apps);

						update_option('_bgc_app_list', $data);

						update_option('_bgc_pdf_download', $pdf_download);

						update_option('_bgc_multiple_charts', $multiple_charts);

						update_option('_bgc_email_optional', $email_optional);

						update_option('_bgc_terms_checkbox', $terms_checkbox);

						update_option('_bgc_autocomplete_paid_orders', $autocomplete_paid_orders);

						delete_option('_tmp_bgc_api_key');
					}
				}
			} else {
				delete_option('_bgc_api_key');
			}

			if (!$error) {
				$updated = true;
			}
		}

		$api_key = get_option('_bgc_api_key');
		$hd_content = get_option('_bgc_hd_content');
		$chart_design = get_option('_bgc_chart_design');
		$apps = get_option('_bgc_apps');
		$pdf_download = get_option('_bgc_pdf_download', 1);
		$multiple_charts = get_option('_bgc_multiple_charts', 1);
		$email_optional = get_option('_bgc_email_optional', 0);
		$terms_checkbox = get_option('_bgc_terms_checkbox', 1);
		$autocomplete_paid_orders = get_option('_bgc_autocomplete_paid_orders', 1);

		$hd_content_list = get_option('_bgc_hd_content_list', []);
		$chart_design_list = get_option('_bgc_chart_design_list', []);
		$app_list = get_option('_bgc_app_list', []);

		?>
		<div class="wrap">
			<nav class="nav-tab-wrapper">
				<a href="<?php echo add_query_arg('page', 'bgc-settings', admin_url('options-general.php')); ?>" class="nav-tab nav-tab-active">
					<?php _e('General', 'bgc'); ?>
				</a>
				<a href="<?php echo add_query_arg('page', 'bgc-translations', admin_url('options-general.php')); ?>" class="nav-tab ">
					<?php _e('Translations', 'bgc'); ?>
				</a>
			</nav>
			<div class="float-left">
				<div class="settings-widget">
					<h2><?php _e('BodyGraph Chart Settings', 'bgc'); ?></h2>
					<div class="settings-wrapper">
						<?php if (isset($updated)) : ?>
							<div class="notification-item success">
								<h2>
									<span class="icon">
										<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/check.svg" alt="<?php _e('Checked', 'bgc'); ?>" class="img-fluid">
									</span>
									<?php _e('Settings saved.', 'bgc'); ?>
								</h2>
							</div>
						<?php endif; ?>
						<?php if (isset($error)) : ?>
							<div class="notice notice-error settings-error">
								<p><strong><?php echo $error; ?></strong></p>
							</div>
						<?php endif; ?>
						<div class="settings-icon">
							<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/setting-image.svg" alt="<?php _e('Settings', 'bgc'); ?>" class="img-fluid">
						</div>
						<form method="post">
							<div class="settings-options">
								<div class="input-item">
									<label for="api_key"><?php _e('Enter your BodyGraph Chart API key:', 'bgc'); ?></label>
									<input type="password" name="api_key" value="<?php echo $api_key; ?>" id="api_key" class="regular-text">
									<div class="overflow-hidden mt-10">
										<a href="https://app.bodygraphchart.com/profile/api-key" target="_blank" class="anchor-shortlink float-left mt-10">
											<?php _e('Get your API key', 'bgc'); ?>
											<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/export.svg" alt="<?php _e('External', 'bgc'); ?>" class="img-fluid">
										</a>
									</div>
									<?php if (!empty($api_key)) : ?>
										<div class="input-item mt-10">
											<label for="hd_content"><?php _e('My HD Content (Language)', 'bgc'); ?></label>
											<div class="select-wrapper">
												<select name="hd_content" id="hd_content">
													<?php foreach ($hd_content_list as $value) : ?>
														<option value="<?php echo $value->name; ?>" <?php selected($value->name, $hd_content); ?>>
															<?php echo $value->name; ?>
														</option>
													<?php endforeach; ?>
												</select>
											</div>
											<a href="https://app.bodygraphchart.com/languages" target="_blank" class="anchor-shortlink mt-10">
												<?php _e('Add New', 'bgc'); ?>
												<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/export.svg" alt="<?php _e('External', 'bgc'); ?>" class="img-fluid">
											</a>
										</div>
										<div class="input-item">
											<label for="chart_design"><?php _e('My Chart Design', 'bgc'); ?></label>
											<div class="select-wrapper">
												<select name="chart_design" id="chart_design">
													<?php foreach ($chart_design_list as $value) : ?>
														<option value="<?php echo $value->name; ?>" <?php selected($value->name, $chart_design); ?>>
															<?php echo $value->name; ?>
														</option>
													<?php endforeach; ?>
												</select>
											</div>
											<a href="https://app.bodygraphchart.com/chart-designs" target="_blank" class="anchor-shortlink mt-10">
												<?php _e('Add New', 'bgc'); ?>
												<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/export.svg" alt="<?php _e('External', 'bgc'); ?>" class="img-fluid">
											</a>
										</div>
										<?php if ($app_list) : ?>
											<div class="checkbox-list">
												<h3><?php _e('My Apps', 'bgc'); ?></h3>
												<?php foreach ($app_list as $value) : ?>
													<div class="checkbox-item">
														<input type="checkbox" name="apps[]" value="<?php echo $value->id; ?>" id="app-<?php echo $value->id; ?>" <?php echo ($apps && in_array($value->id, $apps)) ? 'checked' : ''; ?>>
														<label for="app-<?php echo $value->id; ?>"><?php echo $value->name; ?></label>
													</div>
												<?php endforeach; ?>
												<a href="https://app.bodygraphchart.com/apps" target="_blank" class="anchor-shortlink mt-10">
													<?php _e('Add New', 'bgc'); ?>
													<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/export.svg" alt="<?php _e('External', 'bgc'); ?>" class="img-fluid">
												</a>
											</div>
										<?php endif; ?>
										<div class="checkbox-list">
											<h3><?php _e('Other Options', 'bgc'); ?></h3>
											<!--
											<div class="checkbox-item">
												<input type="checkbox" name="pdf_download" id="pdf_download" value="1" <?php checked(1, $pdf_download); ?>>
												<label for="pdf_download"><?php _e('Allow downloading PDF print of the chart', 'bgc'); ?></label>
											</div>
											-->
											<div class="checkbox-item">
												<input type="checkbox" name="multiple_charts" id="multiple_charts" value="1" <?php checked(1, $multiple_charts); ?>>
												<label for="multiple_charts"><?php _e('Allow storing multiple charts', 'bgc'); ?></label>
											</div>
											<div class="checkbox-item">
												<input type="checkbox" name="email_optional" id="email_optional" value="1" <?php checked(1, $email_optional); ?>>
												<label for="email_optional"><?php _e('Email field is optional', 'bgc'); ?></label>
											</div>
											<div class="checkbox-item">
												<input type="checkbox" name="terms_checkbox" id="terms_checkbox" value="1" <?php checked(1, $terms_checkbox); ?>>
												<label for="terms_checkbox">
													<?php _e('Enable terms and conditions checkbox', 'bgc'); ?>
													<a href="<?php echo add_query_arg('page', 'bgc-translations', admin_url('options-general.php')); ?>"><?php _e('Change text here', 'bgc'); ?></a>
												</label>
											</div>
											<?php if (defined('BGCRW_NAME')) : ?>
												<div class="checkbox-item">
													<input type="checkbox" name="autocomplete_paid_orders" id="autocomplete_paid_orders" value="1" <?php checked(1, $autocomplete_paid_orders); ?>>
													<label for="autocomplete_paid_orders"><?php _e('Autocomplete paid orders', 'bgc'); ?></label>
												</div>
											<?php endif; ?>
										</div>
									<?php endif; ?>
									<div class="overflow-hidden mt-10">
										<button name="submit" class="green-btn float-right"><?php _e('Save Changes', 'bgc'); ?></button>
									</div>
								</div>
							</div>
						</form>
					</div>
				</div>
			</div>
			<div class="float-right">
				<div class="information-box">
					<h3><?php _e('Shortcodes', 'bgc'); ?></h3>
					<div class="info-box">
						<span>
							<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/info.svg" alt="<?php _e('Info', 'bgc'); ?>" class="img-fluid">
						</span>
						<p><?php _e('You can utilize the following shortcodes to create pages for displaying charts. Additionally, please copy and paste the shortcodes onto the different pages: one for the birth submission form and another to display the chart.', 'bgc'); ?></p>
					</div>
					<div class="shortcode-item">
						<h4><?php _e('Birthdate submission form', 'bgc'); ?></h4>
						<div class="shortcode-field">
							<input type="text" value="[bgc_form]" readonly>
							<button class="copy-shortcode"><?php _e('Copy', 'bgc'); ?></button>
						</div>
					</div>
					<div class="shortcode-item">
						<h4><?php _e('BodyGraph chart result', 'bgc'); ?></h4>
						<div class="shortcode-field">
							<input type="text" value="[bgc_result]" readonly>
							<button class="copy-shortcode"><?php _e('Copy', 'bgc'); ?></button>
						</div>
					</div>
				</div>
				<div class="information-box">
					<h3><?php _e('Tutorials:', 'bgc'); ?></h3>
					<div class="quick-links">
						<a href="https://help.bodygraphchart.com/help/how-to-setup-hd-business-website/" target="_blank" class="anchor-link">
							How to setup HD Business Website
							<img src="<?php echo BGC_PLUGIN_URL; ?>assets/backend/images/export.svg" alt="<?php _e('External', 'bgc'); ?>" class="img-fluid">
						</a>
					</div>
				</div>
				<div class="information-box">
					<h3><?php _e('Links:', 'bgc'); ?></h3>
					<div class="quick-links">
						<a href="https://bodygraphchart.com/" target="_blank" class="anchor-link">
							<?php _e('Homepage', 'bgc'); ?>
						</a>
						<a href="https://bodygraphchart.com/docs/" target="_blank" class="anchor-link">
							<?php _e('Documentation', 'bgc'); ?>
						</a>
						<a href="mailto:suppor@bodygraphchart.com" target="_blank" class="anchor-link">
							<?php _e('Support', 'bgc'); ?>
						</a>
					</div>
				</div>
			</div>
		</div>
		<?php if (isset($_GET['bgc-setup']) && get_option('_tmp_bgc_api_key')) : ?>
			<script type="text/javascript">
				jQuery(function ($) {
					$('#api_key').val('<?php echo get_option('_tmp_bgc_api_key'); ?>');

					setTimeout(function () {
						$('.green-btn').click();
					}, 100);
				});
			</script>
		<?php endif; ?>
		<?php
	}
}

if (!function_exists('bgc_translations_page')) {
	function bgc_translations_page() {
		if (isset($_POST['submit'])) {
			update_option('_bgc_translations', $_POST['translations']);
		}

		$translations = bgc_get_translated_string();

		?>
		<div class="wrap">
			<nav class="nav-tab-wrapper">
				<a href="<?php echo add_query_arg('page', 'bgc-settings', admin_url('options-general.php')); ?>" class="nav-tab">
					<?php _e('General', 'bgc'); ?>
				</a>
				<a href="<?php echo add_query_arg('page', 'bgc-translations', admin_url('options-general.php')); ?>" class="nav-tab nav-tab-active">
					<?php _e('Translations', 'bgc'); ?>
				</a>
			</nav>
			<h1><?php _e('BodyGraph Chart Translations', 'bgc'); ?></h1>
			<?php if (isset($_POST['submit'])) : ?>
				<div id="setting-error-settings_updated" class="notice notice-success settings-error is-dismissible">
					<p><strong><?php _e('Settings saved.', 'bgc'); ?></strong></p>
					<button type="button" class="notice-dismiss"><span class="screen-reader-text"><?php _e('Dismiss this notice.', 'bgc'); ?></span></button>
				</div>
			<?php endif; ?>
			<form method="post">
				<h2 class="title"><?php _e('Form', 'bgc'); ?></h2>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php _e('Title', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][title]" value="<?php echo $translations['form']['title']; ?>" class="regular-text" id="title">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="first_name"><?php _e('First Name', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][first_name]" value="<?php echo $translations['form']['first_name']; ?>" class="regular-text" id="first_name">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="last_name"><?php _e('Last Name', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][last_name]" value="<?php echo $translations['form']['last_name']; ?>" class="regular-text" id="last_name">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="year"><?php _e('Year', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][year]" value="<?php echo $translations['form']['year']; ?>" class="regular-text" id="year">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="month"><?php _e('Month', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][month]" value="<?php echo $translations['form']['month']; ?>" class="regular-text" id="month">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="day"><?php _e('Day', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][day]" value="<?php echo $translations['form']['day']; ?>" class="regular-text" id="day">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="hour"><?php _e('Hour', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][hour]" value="<?php echo $translations['form']['hour']; ?>" class="regular-text" id="hour">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="minute"><?php _e('Minute', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][minute]" value="<?php echo $translations['form']['minute']; ?>" class="regular-text" id="minute">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="location"><?php _e('Location', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][location]" value="<?php echo $translations['form']['location']; ?>" class="regular-text" id="location">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="email"><?php _e('Email', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][email]" value="<?php echo $translations['form']['email']; ?>" class="regular-text" id="email">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="submit"><?php _e('Submit', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][submit]" value="<?php echo $translations['form']['submit']; ?>" class="regular-text" id="submit">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="newsletter_terms"><?php _e('Newsletter Terms', 'bgc'); ?></label>
							</th>
							<td>
								<textarea name="translations[form][newsletter_terms]" class="regular-text" id="newsletter_terms"><?php echo $translations['form']['newsletter_terms']; ?></textarea>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="confirmation_title"><?php _e('Confirmation Title', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][confirmation_title]" value="<?php echo $translations['form']['confirmation_title']; ?>" class="regular-text" id="confirmation_title">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="confirmation_terms"><?php _e('Confirmation Terms', 'bgc'); ?></label>
							</th>
							<td>
								<textarea name="translations[form][confirmation_terms]" class="regular-text" id="confirmation_terms"><?php echo $translations['form']['confirmation_terms']; ?></textarea>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="continue"><?php _e('Continue', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][continue]" value="<?php echo $translations['form']['continue']; ?>" class="regular-text" id="continue">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="return"><?php _e('Return', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[form][return]" value="<?php echo $translations['form']['return']; ?>" class="regular-text" id="return">
							</td>
						</tr>
					</tbody>
				</table>
				<h2 class="title"><?php _e('Result', 'bgc'); ?></h2>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="save_chart"><?php _e('Save Chart', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[result][save_chart]" value="<?php echo $translations['result']['save_chart']; ?>" class="regular-text" id="save_chart">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="design"><?php _e('Design', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[result][design]" value="<?php echo $translations['result']['design']; ?>" class="regular-text" id="design">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="personality"><?php _e('Personality', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[result][personality]" value="<?php echo $translations['result']['personality']; ?>" class="regular-text" id="personality">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="birth_date"><?php _e('Birth Date', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[result][birth_date]" value="<?php echo $translations['result']['birth_date']; ?>" class="regular-text" id="birth_date">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="design_date"><?php _e('Design Date', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[result][design_date]" value="<?php echo $translations['result']['design_date']; ?>" class="regular-text" id="design_date">
							</td>
						</tr>
					</tbody>
				</table>
				<h2 class="title"><?php _e('Account', 'bgc'); ?></h2>
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="my_charts"><?php _e('My Charts', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[account][my_charts]" value="<?php echo $translations['account']['my_charts']; ?>" class="regular-text" id="my_charts">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="create_new"><?php _e('Create New Chart', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[account][create_new]" value="<?php echo $translations['account']['create_new']; ?>" class="regular-text" id="create_new">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="view_chart"><?php _e('View Chart', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[account][view_chart]" value="<?php echo $translations['account']['view_chart']; ?>" class="regular-text" id="view_chart">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="no_charts"><?php _e('No saved charts', 'bgc'); ?></label>
							</th>
							<td>
								<input type="text" name="translations[account][no_charts]" value="<?php echo $translations['account']['no_charts']; ?>" class="regular-text" id="no_charts">
							</td>
						</tr>
					</tbody>
				</table>
				<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}
}
