<?php

if (!defined('WPINC')) {
	die;
}

if (!function_exists('bgc_template_redirect')) {
	add_action('template_redirect', 'bgc_template_redirect');

	function bgc_template_redirect() {
		if (session_status() === PHP_SESSION_NONE) {
			session_start();
		}

		if (isset($_REQUEST['bgch'])) {
			global $wpdb, $bgc_data;

			$chart_hash = isset($_REQUEST['bgch']) ? $_REQUEST['bgch'] : null;
			$bgc_data = isset($_SESSION['_bgc_data']) ? $_SESSION['_bgc_data'] : null;

			if ($chart_hash) {
				$row = $wpdb->get_row($wpdb->prepare("SELECT chart_data FROM {$wpdb->prefix}bgc_charts WHERE chart_hash = %s", $chart_hash));

				if ($row) {
					$_SESSION['_bgc_data'] = $bgc_data = json_decode($row->chart_data);
				}
			}

			if (!isset($bgc_data->Properties)) {
				if (is_user_logged_in() && bgc_has_charts()) {
					$rows = $wpdb->get_results($wpdb->prepare("SELECT chart_hash FROM {$wpdb->prefix}bgc_charts WHERE user_id = %s ORDER BY created_at LIMIT 1", get_current_user_id()));

					if ($rows) {
						$chart_page = bgc_get_chart_page();

						if ($chart_page) {
							wp_redirect(add_query_arg('bgch', $rows[0]->chart_hash, get_permalink($chart_page->ID)));
						} else {
							wp_redirect(add_query_arg('bgch', $rows[0]->chart_hash, remove_query_arg('bgc-delete')));
						}
					}
				}

				$form_page = bgc_get_form_page();

				if ($form_page) {
					wp_redirect(get_permalink($form_page->ID));
				} else {
					wp_redirect(home_url('/'));
				}

				exit;
			}
		}

		if (isset($_REQUEST['bgc-generate'])) {
			$first_name = filter_input(INPUT_POST, '_first_name');
			$last_name = filter_input(INPUT_POST, '_last_name');
			$year = filter_input(INPUT_POST, '_year');
			$month = filter_input(INPUT_POST, '_month');
			$day = filter_input(INPUT_POST, '_day');
			$hour = filter_input(INPUT_POST, '_hour');
			$ampm = filter_input(INPUT_POST, '_ampm');
			$minute = filter_input(INPUT_POST, '_minute');
			$location = filter_input(INPUT_POST, '_location');
			$timezone = filter_input(INPUT_POST, '_timezone');
			$email = filter_input(INPUT_POST, '_email');
			$confirm = filter_input(INPUT_POST, '_confirm');

			if ($ampm == 'pm' && $hour != 12) {
				$hour = $hour + 12;
			} else if ($ampm == 'am' && $hour == 12) {
				$hour = '00';
			}

			$response = [
				'status' => 'error',
				'message' => __('Oops something went wrong, try again later.', 'bgc')
			];

			$data = wp_remote_get(add_query_arg([
				'api_key' => get_option('_bgc_api_key'),
				'date' => sprintf('%s-%s-%s %s:%s', $year, $month, $day, $hour, $minute),
				'timezone' => $timezone,
				'language' => get_option('_bgc_hd_content'),

				'_name' => sprintf('%s %s', $first_name, $last_name),
				'_birth_place' => $location,
				'_timezone' => $timezone,
				'_email' => $email,
				'_apps' => get_option('_bgc_apps', [])
			], 'https://api.bodygraphchart.com/v221006/hd-data'));

			if (!is_wp_error($data)) {
				$data = json_decode(wp_remote_retrieve_body($data));

				if (isset($data->Properties)) {
					if (isset($_REQUEST['bgch'])) {
						global $bgc_data;

						if (bgc_can_edit_chart($bgc_data)) {
							global $wpdb;

							$chart_hash = sha1(serialize($data));

							$wpdb->update($wpdb->prefix . 'bgc_charts' , [
								'chart_hash' => $chart_hash,
								'chart_data' => json_encode($data)
							], ['user_id' => get_current_user_id(), 'chart_hash' => $_REQUEST['bgch']]);
						}
					}

					if (!isset($chart_hash)) {
						$_SESSION['_bgc_data'] = $data;
					}

					$target_page = home_url('/');

					$chart_page = bgc_get_chart_page();

					if ($chart_page) {
						$target_page = get_permalink($chart_page->ID);
					}

					if ($confirm) {
						global $post;

						$product = wc_get_product($post->ID);

						remove_action('woocommerce_add_to_cart', 'bgcrw_woocommerce_add_to_cart', 10);

						WC()->cart->add_to_cart($product->get_id(), 1, null, null, [
							'report_id' => $product->get_meta('_bgcrw_report'),
							'name' => $data->Properties->Name,
							'date' => sprintf('%s-%s-%s %s:%s', $year, $month, $day, $hour, $minute),
							'location' => $data->Properties->BirthPlace,
							'timezone' => $data->Properties->Timezone
						]);

						$target_page = add_query_arg('added', 1, $target_page);
					}

					$response = [
						'status' => 'success',
						'redirect_to' => add_query_arg('bgch', (isset($chart_hash) ? $chart_hash : ''), $target_page)
					];
				}
			}

			wp_send_json($response);
		}

		if (isset($_GET['bgc-edit'])) {
			$chart_hash = isset($_REQUEST['bgch']) ? $_REQUEST['bgch'] : null;

			if ($chart_hash) {
				global $wpdb;

				$row = $wpdb->get_row($wpdb->prepare("SELECT chart_data FROM {$wpdb->prefix}bgc_charts WHERE chart_hash = %s", $chart_hash));

				if ($row && bgc_can_edit_chart(json_decode($row->chart_data))) {
					$form_page = bgc_get_form_page();

					if ($form_page) {
						wp_redirect(add_query_arg('bgch', $chart_hash, get_permalink($form_page->ID)));
					} else {
						wp_redirect(add_query_arg('bgch', $chart_hash, home_url('/')));
					}

					exit;
				}
			}
		}

		if (isset($_REQUEST['bgc-delete'])) {
			$chart_hash = isset($_REQUEST['bgch']) ? $_REQUEST['bgch'] : null;

			if ($chart_hash) {
				global $wpdb;

				$row = $wpdb->get_row($wpdb->prepare("SELECT id, chart_data FROM {$wpdb->prefix}bgc_charts WHERE chart_hash = %s", $chart_hash));

				if ($row && bgc_can_delete_chart(json_decode($row->chart_data))) {
					$wpdb->delete($wpdb->prefix . 'bgc_charts', ['id' => $row->id]);

					if (class_exists('WooCommerce')) {
						wc_add_notice(__('Deleted!', 'bgc'), 'notice');
					}

					$row = $wpdb->get_row($wpdb->prepare("SELECT chart_hash FROM {$wpdb->prefix}bgc_charts WHERE user_id = %s", get_current_user_id()));

					if ($row) {
						$chart_page = bgc_get_chart_page();

						if ($chart_page) {
							wp_redirect(add_query_arg('bgch', $row->chart_hash, get_permalink($chart_page->ID)));
						} else {
							wp_redirect(add_query_arg('bgch', $row->chart_hash, remove_query_arg('bgc-delete')));
						}
					} else {
						$form_page = bgc_get_form_page();

						if ($form_page) {
							wp_redirect(get_permalink($form_page->ID));
						} else {
							wp_redirect(home_url('/'));
						}
					}

					exit;
				}
			}
		}

		if (isset($_REQUEST['bgc-save'])) {
			if (isset($_SESSION['_bgc_data']) && bgc_can_save_chart($_SESSION['_bgc_data'])) {
				global $wpdb;

				$data = $_SESSION['_bgc_data'];
				$chart_hash = sha1(serialize($data));

				$wpdb->insert($wpdb->prefix . 'bgc_charts', [
					'user_id' => get_current_user_id(),
					'chart_hash' => $chart_hash,
					'chart_data' => json_encode($data),
					'created_at' => current_time('mysql')
				]);

				unset($_SESSION['_bgc_data']);

				if (class_exists('WooCommerce')) {
					wc_add_notice(__('Saved!', 'bgc'), 'notice');
				}

				$chart_page = bgc_get_chart_page();

				if ($chart_page) {
					wp_redirect(add_query_arg('bgch', $chart_hash, get_permalink($chart_page->ID)));
				} else {
					wp_redirect(add_query_arg('bgch', $chart_hash));
				}

				exit;
			}
		}
	}
}

if (!function_exists('bgc_form_shortcode')) {
	add_shortcode('bgc_form', 'bgc_form_shortcode');

	function bgc_form_shortcode($atts) {
		$atts = shortcode_atts([
			'title' => '',
			'confirm' => false
		], $atts);

		$atts['api_key'] = get_option('_bgc_api_key');

		if (isset($_REQUEST['bgch'])) {
			global $bgc_data;

			if (bgc_can_edit_chart($bgc_data)) {
				$name = trim(esc_attr($bgc_data->Properties->Name));
				$last_name = (strpos($bgc_data->Properties->Name, ' ') === false) ? '' : preg_replace('#.*\s([\w-]*)$#', '$1', $name);
				$first_name = trim(preg_replace('#' . preg_quote($last_name, '#') . '#', '', $name));

				$date = new Datetime($bgc_data->Properties->BirthDateLocalStandard);

				$atts['first_name'] = $first_name;
				$atts['last_name'] = $last_name;
				$atts['year'] = $date->format('Y');
				$atts['month'] = $date->format('m');
				$atts['day'] = $date->format('d');
				$atts['hour'] = $date->format('h');
				$atts['ampm'] = $date->format('a');
				$atts['minute'] = $date->format('m');
				$atts['location'] = esc_attr($bgc_data->Properties->BirthPlace);
				$atts['timezone'] = esc_attr($bgc_data->Properties->Timezone);
			}
		}

		$atts['translations'] = bgc_get_translated_string();

		if ($atts['title'] !== '0') {
			$atts['title'] = $atts['translations']['form']['title'];
		}

		bgc_enqueue_scripts();

		return bgc_get_template('form.php', $atts);
	}
}

if (!function_exists('bgc_chart_shortcode')) {
	add_shortcode('bgc_chart', 'bgc_chart_shortcode');

	function bgc_chart_shortcode($atts) {
		$atts = shortcode_atts([], $atts);

		global $bgc_data;

		if (!$bgc_data) {
			return '';
		}

		$atts['charts'] = bgc_charts_list();

		$atts['chart_design_options'] = get_option('_bgc_chart_design_options');
		$atts['data'] = $bgc_data;

		bgc_enqueue_scripts();

		wp_localize_script('bgc', 'bgc', [
			'ajaxurl' => admin_url('admin-ajax.php'),
			'data' => $atts['data'],
			'background' => $atts['chart_design_options']->background,
			'planet_icons' => $atts['chart_design_options']->planet_icon,
			'colors' => $atts['chart_design_options']->colors,
			'translations' => bgc_get_translated_string()
		]);

		return bgc_get_template('chart.php', $atts);
	}
}
