<?php

if (!defined('WPINC')) {
	die;
}

if (!function_exists('bgc_locate_template')) {
	function bgc_locate_template($template_name, $template_path = '', $default_path = '') {
		if (!$template_path) {
			$template_path = 'bgc/';
		}

		if (!$default_path) {
			$default_path = BGC_PLUGIN_DIR . 'templates/';
		}

		$template = locate_template([$template_path . $template_name, $template_name]);

		if (!$template) {
			$template = $default_path . $template_name;
		}

		return apply_filters('bgc_locate_template', $template, $template_name, $template_path, $default_path);
	}
}

if (!function_exists('bgc_get_template')) {
	function bgc_get_template($template_name, $args = [], $tempate_path = '', $default_path = '') {
		if (isset($args) && is_array($args)) {
			extract($args);
		}

		$template_file = bgc_locate_template($template_name, $tempate_path, $default_path);

		if (!file_exists($template_file)) {
			_doing_it_wrong(__FUNCTION__, sprintf('<code>%s</code> does not exist.', $template_file), '1.0.0');

			return;
		}

		ob_start();

		include $template_file;

		return ob_get_clean();
	}
}

if (!function_exists('bgc_enqueue_scripts')) {
	function bgc_enqueue_scripts() {
		wp_enqueue_style('bgc-autocomplete', BGC_PLUGIN_URL . 'assets/css/autocomplete.css');
		wp_enqueue_style('bgc', BGC_PLUGIN_URL . 'assets/css/bgc.css');

		wp_enqueue_script('bgc-autocomplete', BGC_PLUGIN_URL . 'assets/js/autocomplete.js');
		wp_enqueue_script('bgc', BGC_PLUGIN_URL . 'assets/js/bgc.js', ['bgc-autocomplete']);
	}
}

if (!function_exists('bgc_generate_initials')) {
	function bgc_generate_initials($name) {
		$words = explode(' ', $name);

		if (count($words) >= 2) {
			return mb_strtoupper(mb_substr($words[0], 0, 1, 'UTF-8') . mb_substr(end($words), 0, 1, 'UTF-8'), 'UTF-8');
		}

		preg_match_all('#([A-Z]+)#', $name, $capitals);

		if (count($capitals[1]) >= 2) {
			return mb_substr(implode('', $capitals[1]), 0, 2, 'UTF-8');
		}

		return mb_strtoupper(mb_substr($name, 0, 2, 'UTF-8'), 'UTF-8');
	}
}

if (!function_exists('bgc_get_form_page')) {
	function bgc_get_form_page() {
		global $wpdb;

		$id = $wpdb->get_var("SELECT ID FROM {$wpdb->posts} WHERE post_content LIKE '%[bgc_form%' AND post_status = 'publish'");

		if ($id) {
			return get_post($id);
		}

		return null;
	}
}

if (!function_exists('bgc_get_chart_page')) {
	function bgc_get_chart_page() {
		global $wpdb;

		$id = $wpdb->get_var("SELECT ID FROM {$wpdb->posts} WHERE post_content LIKE '%[bgc_chart]%' AND post_status = 'publish'");

		if ($id) {
			return get_post($id);
		}

		return null;
	}
}

if (!function_exists('bgc_has_charts')) {
	function bgc_has_charts() {
		if (!is_user_logged_in()) {
			return false;
		}

		$multiple_charts = get_option('_bgc_multiple_charts', 1);

		if (!$multiple_charts) {
			return false;
		}

		global $wpdb;

		$charts = $wpdb->get_var($wpdb->prepare("SELECT COUNT(id) FROM {$wpdb->prefix}bgc_charts WHERE user_id = %d", get_current_user_id()));

		if ($charts) {
			return true;
		}

		return false;
	}
}

if (!function_exists('bgc_charts_list')) {
	function bgc_charts_list() {
		if (!bgc_has_charts()) {
			return [];
		}

		global $wpdb;

		$data = [];

		$rows = $wpdb->get_results($wpdb->prepare("SELECT chart_hash, chart_data FROM {$wpdb->prefix}bgc_charts WHERE user_id = %s ORDER BY created_at", get_current_user_id()));

		if ($rows) {
			foreach ($rows as $row) {
				$data[$row->chart_hash] = json_decode($row->chart_data);
			}
		}

		return $data;
	}
}

if (!function_exists('bgc_can_edit_chart')) {
	function bgc_can_edit_chart($data) {
		return bgc_can_delete_chart($data);
	}
}

if (!function_exists('bgc_can_delete_chart')) {
	function bgc_can_delete_chart($data) {
		if (!is_user_logged_in()) {
			return false;
		}

		global $wpdb;

		$user_id = get_current_user_id();
		$chart_hash = sha1(serialize($data));

		$chart_exists = $wpdb->get_var($wpdb->prepare("SELECT id FROM {$wpdb->prefix}bgc_charts WHERE user_id = %d AND chart_hash = %s", $user_id, $chart_hash));

		if ($chart_exists) {
			return true;
		}

		return false;
	}
}

if (!function_exists('bgc_can_save_chart')) {
	function bgc_can_save_chart($data) {
		if (!is_user_logged_in()) {
			return false;
		}

		$multiple_charts = get_option('_bgc_multiple_charts', 1);

		if (!$multiple_charts) {
			return false;
		}

		if (!isset($_SESSION['_bgc_data'])) {
			return false;
		}

		global $wpdb;

		$user_id = get_current_user_id();
		$chart_hash = sha1(serialize($data));

		$chart_exists = $wpdb->get_var($wpdb->prepare("SELECT id FROM {$wpdb->prefix}bgc_charts WHERE user_id = %d AND chart_hash = %s", $user_id, $chart_hash));

		if ($chart_exists) {
			return false;
		}

		return true;
	}
}

if (!function_exists('bgc_get_translated_string')) {
	function bgc_get_translated_string($section = '', $key = '') {
		$translations = get_option('_bgc_translations', [
			'form' => [
				'title' => 'Get Free Chart',
				'first_name' => 'First Name',
				'last_name' => 'Last Name',
				'year' => 'Birth Year',
				'month' => 'Birth Month',
				'day' => 'Birth Day',
				'hour' => 'Birth Hour',
				'minute' => 'Birth Minute',
				'location' => 'Birth Location',
				'email' => 'Email Address',
				'submit' => 'View Your Chart',
				'newsletter_terms' => 'I agree to the <a href="/terms/" target="_blank">terms and conditions</a>',
				'confirmation_title' => 'Please confirm the Birth Details for your order',
				'confirmation_terms' => 'I confirm that the above details are correct and I understand that my bespoke Human Design Reports and products will be created immediately based on the information I have provided above',
				'continue' => 'Continue',
				'return' => 'Return'
			],
			'result' => [
				'save_chart' => 'Save Chart',
				'design' => 'Design',
				'personality' => 'Personality',
				'birth_date' => 'Birth Date',
				'design_date' => 'Design Date'
			],
			'account' => [
				'my_charts' => 'My Charts',
				'create_new' => 'Create New Chart',
				'view_chart' => 'View Chart',
				'no_charts' => 'No saved charts',
			]
		]);

		if ($section && $key) {
			return $translations[$section][$key];
		}

		return $translations;
	}
}
